tlslite.utils.RC4.RC4

Package tlslite :: Package utils :: Module RC4 :: Class RC4 |
[show private | hide private]
[frames | no frames]

## Class RC4

Known Subclasses:
  `Cryptlib_RC4`, `OpenSSL_RC4`, `PyCrypto_RC4`, `Python_RC4`

Method Summary
| `__init__(self, keyBytes, implementation)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net